/// ### NameStatus
/// - Enum for Status of Provided Name
enum NameStatus {
  /// `NameStatus.Default`: Default Status and Type.
  Default,

  /// `NameStatus.Returning`: Name is taken, user is returning.
  Returning,

  /// `NameStatus.Available`: Name length is < 4 characters.
  TooShort,

  /// `NameStatus.Available`: Name is Available.
  Available,

  /// `NameStatus.Unavailable`: Name is Taken.
  Unavailable,

  /// `NameStatus.Blocked`: Name is on Blocked List.
  Blocked,

  /// `NameStatus.Restricted`: Name is on Restricted List.
  Restricted,

  /// `NameStatus.DeviceRegistered`: Device is already registered.
  DeviceRegistered,

  /// `NameStatus.InvalidCharacters`: Name has invalid characters.
  InvalidCharacters,
}

/// ### NameStatusUtils
/// Dart Extension for `NameStatus` enum
extension NameStatusUtils on NameStatus {
  /// Checks if NewSNameStatus is Valid
  bool get isValid {
    switch (this) {
      case NameStatus.Available:
        return true;
      default:
        return false;
    }
  }
}

/// ### NameCheckType
/// - Enum for Type of Check to Perform
enum NameCheckType {
  /// `NameCheckType.All`: Check for all NameStatus
  All,

  /// `NameCheckType.Available`: Checks if Name is Available
  Available,

  /// `NameCheckType.Blocked`: Checks if Name is Blocked
  Blocked,

  /// `NameCheckType.Restricted`: Checks if Name is Restricted
  Restricted,

  /// `NameCheckType.Unblocked`: Checks if Name is Unblocked
  Unblocked,

  /// `NameCheckType.Unrestricted`: Checks if Name is Unrestricted
  Unrestricted,

  /// `NameCheckType.Unavailable`: Checks if Name is Unavailable
  Unavailable,
}
